@@ -1,4 +1,5 @@
 import os
+import sys
 
 from configobj import ConfigObj
 
@@ -15,8 +16,8 @@ def get_server_config():
 
   return servers
 
-def p(s, args=()):
-  print "\n  " + s % args
+def p(s, args=(), out=sys.stdout):
+  print >> out, "\n  " + s % args
 
 def expand_range(r):
   def expand(s):
